#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MerchantCard import MerchantCard
from alipay.aop.api.domain.CardUserInfo import CardUserInfo
from alipay.aop.api.domain.MerchantMenber import MerchantMenber
from alipay.aop.api.domain.PaidOuterCardExtraInfoDTO import PaidOuterCardExtraInfoDTO


class AlipayMarketingCardOpenModel(object):

    def __init__(self):
        self._card_ext_info = None
        self._card_template_id = None
        self._card_user_info = None
        self._member_ext_info = None
        self._open_card_channel = None
        self._open_card_channel_id = None
        self._out_serial_no = None
        self._paid_outer_card_info = None

    @property
    def card_ext_info(self):
        return self._card_ext_info

    @card_ext_info.setter
    def card_ext_info(self, value):
        if isinstance(value, MerchantCard):
            self._card_ext_info = value
        else:
            self._card_ext_info = MerchantCard.from_alipay_dict(value)
    @property
    def card_template_id(self):
        return self._card_template_id

    @card_template_id.setter
    def card_template_id(self, value):
        self._card_template_id = value
    @property
    def card_user_info(self):
        return self._card_user_info

    @card_user_info.setter
    def card_user_info(self, value):
        if isinstance(value, CardUserInfo):
            self._card_user_info = value
        else:
            self._card_user_info = CardUserInfo.from_alipay_dict(value)
    @property
    def member_ext_info(self):
        return self._member_ext_info

    @member_ext_info.setter
    def member_ext_info(self, value):
        if isinstance(value, MerchantMenber):
            self._member_ext_info = value
        else:
            self._member_ext_info = MerchantMenber.from_alipay_dict(value)
    @property
    def open_card_channel(self):
        return self._open_card_channel

    @open_card_channel.setter
    def open_card_channel(self, value):
        self._open_card_channel = value
    @property
    def open_card_channel_id(self):
        return self._open_card_channel_id

    @open_card_channel_id.setter
    def open_card_channel_id(self, value):
        self._open_card_channel_id = value
    @property
    def out_serial_no(self):
        return self._out_serial_no

    @out_serial_no.setter
    def out_serial_no(self, value):
        self._out_serial_no = value
    @property
    def paid_outer_card_info(self):
        return self._paid_outer_card_info

    @paid_outer_card_info.setter
    def paid_outer_card_info(self, value):
        if isinstance(value, PaidOuterCardExtraInfoDTO):
            self._paid_outer_card_info = value
        else:
            self._paid_outer_card_info = PaidOuterCardExtraInfoDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.card_ext_info:
            if hasattr(self.card_ext_info, 'to_alipay_dict'):
                params['card_ext_info'] = self.card_ext_info.to_alipay_dict()
            else:
                params['card_ext_info'] = self.card_ext_info
        if self.card_template_id:
            if hasattr(self.card_template_id, 'to_alipay_dict'):
                params['card_template_id'] = self.card_template_id.to_alipay_dict()
            else:
                params['card_template_id'] = self.card_template_id
        if self.card_user_info:
            if hasattr(self.card_user_info, 'to_alipay_dict'):
                params['card_user_info'] = self.card_user_info.to_alipay_dict()
            else:
                params['card_user_info'] = self.card_user_info
        if self.member_ext_info:
            if hasattr(self.member_ext_info, 'to_alipay_dict'):
                params['member_ext_info'] = self.member_ext_info.to_alipay_dict()
            else:
                params['member_ext_info'] = self.member_ext_info
        if self.open_card_channel:
            if hasattr(self.open_card_channel, 'to_alipay_dict'):
                params['open_card_channel'] = self.open_card_channel.to_alipay_dict()
            else:
                params['open_card_channel'] = self.open_card_channel
        if self.open_card_channel_id:
            if hasattr(self.open_card_channel_id, 'to_alipay_dict'):
                params['open_card_channel_id'] = self.open_card_channel_id.to_alipay_dict()
            else:
                params['open_card_channel_id'] = self.open_card_channel_id
        if self.out_serial_no:
            if hasattr(self.out_serial_no, 'to_alipay_dict'):
                params['out_serial_no'] = self.out_serial_no.to_alipay_dict()
            else:
                params['out_serial_no'] = self.out_serial_no
        if self.paid_outer_card_info:
            if hasattr(self.paid_outer_card_info, 'to_alipay_dict'):
                params['paid_outer_card_info'] = self.paid_outer_card_info.to_alipay_dict()
            else:
                params['paid_outer_card_info'] = self.paid_outer_card_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCardOpenModel()
        if 'card_ext_info' in d:
            o.card_ext_info = d['card_ext_info']
        if 'card_template_id' in d:
            o.card_template_id = d['card_template_id']
        if 'card_user_info' in d:
            o.card_user_info = d['card_user_info']
        if 'member_ext_info' in d:
            o.member_ext_info = d['member_ext_info']
        if 'open_card_channel' in d:
            o.open_card_channel = d['open_card_channel']
        if 'open_card_channel_id' in d:
            o.open_card_channel_id = d['open_card_channel_id']
        if 'out_serial_no' in d:
            o.out_serial_no = d['out_serial_no']
        if 'paid_outer_card_info' in d:
            o.paid_outer_card_info = d['paid_outer_card_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AssetDeliveryProcessInfo import AssetDeliveryProcessInfo


class AntMerchantExpandDeliveryProcessSyncModel(object):

    def __init__(self):
        self._asset_delivery_process_info = None

    @property
    def asset_delivery_process_info(self):
        return self._asset_delivery_process_info

    @asset_delivery_process_info.setter
    def asset_delivery_process_info(self, value):
        if isinstance(value, AssetDeliveryProcessInfo):
            self._asset_delivery_process_info = value
        else:
            self._asset_delivery_process_info = AssetDeliveryProcessInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.asset_delivery_process_info:
            if hasattr(self.asset_delivery_process_info, 'to_alipay_dict'):
                params['asset_delivery_process_info'] = self.asset_delivery_process_info.to_alipay_dict()
            else:
                params['asset_delivery_process_info'] = self.asset_delivery_process_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandDeliveryProcessSyncModel()
        if 'asset_delivery_process_info' in d:
            o.asset_delivery_process_info = d['asset_delivery_process_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PublicMsgKeyword import PublicMsgKeyword
from alipay.aop.api.domain.PublicMsgKeyword import PublicMsgKeyword


class AlipayOpenPublicTemplateMessageAddModel(object):

    def __init__(self):
        self._keyword_list = None
        self._lib_code = None
        self._opt_list = None

    @property
    def keyword_list(self):
        return self._keyword_list

    @keyword_list.setter
    def keyword_list(self, value):
        if isinstance(value, list):
            self._keyword_list = list()
            for i in value:
                if isinstance(i, PublicMsgKeyword):
                    self._keyword_list.append(i)
                else:
                    self._keyword_list.append(PublicMsgKeyword.from_alipay_dict(i))
    @property
    def lib_code(self):
        return self._lib_code

    @lib_code.setter
    def lib_code(self, value):
        self._lib_code = value
    @property
    def opt_list(self):
        return self._opt_list

    @opt_list.setter
    def opt_list(self, value):
        if isinstance(value, list):
            self._opt_list = list()
            for i in value:
                if isinstance(i, PublicMsgKeyword):
                    self._opt_list.append(i)
                else:
                    self._opt_list.append(PublicMsgKeyword.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.keyword_list:
            if isinstance(self.keyword_list, list):
                for i in range(0, len(self.keyword_list)):
                    element = self.keyword_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.keyword_list[i] = element.to_alipay_dict()
            if hasattr(self.keyword_list, 'to_alipay_dict'):
                params['keyword_list'] = self.keyword_list.to_alipay_dict()
            else:
                params['keyword_list'] = self.keyword_list
        if self.lib_code:
            if hasattr(self.lib_code, 'to_alipay_dict'):
                params['lib_code'] = self.lib_code.to_alipay_dict()
            else:
                params['lib_code'] = self.lib_code
        if self.opt_list:
            if isinstance(self.opt_list, list):
                for i in range(0, len(self.opt_list)):
                    element = self.opt_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.opt_list[i] = element.to_alipay_dict()
            if hasattr(self.opt_list, 'to_alipay_dict'):
                params['opt_list'] = self.opt_list.to_alipay_dict()
            else:
                params['opt_list'] = self.opt_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicTemplateMessageAddModel()
        if 'keyword_list' in d:
            o.keyword_list = d['keyword_list']
        if 'lib_code' in d:
            o.lib_code = d['lib_code']
        if 'opt_list' in d:
            o.opt_list = d['opt_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItemSkuPropertyInfo(object):

    def __init__(self):
        self._property_key = None
        self._property_value = None

    @property
    def property_key(self):
        return self._property_key

    @property_key.setter
    def property_key(self, value):
        self._property_key = value
    @property
    def property_value(self):
        return self._property_value

    @property_value.setter
    def property_value(self, value):
        self._property_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.property_key:
            if hasattr(self.property_key, 'to_alipay_dict'):
                params['property_key'] = self.property_key.to_alipay_dict()
            else:
                params['property_key'] = self.property_key
        if self.property_value:
            if hasattr(self.property_value, 'to_alipay_dict'):
                params['property_value'] = self.property_value.to_alipay_dict()
            else:
                params['property_value'] = self.property_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemSkuPropertyInfo()
        if 'property_key' in d:
            o.property_key = d['property_key']
        if 'property_value' in d:
            o.property_value = d['property_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchBoxBasicInfo(object):

    def __init__(self):
        self._box_id = None
        self._brand_id = None
        self._name = None
        self._status = None
        self._target_appid = None

    @property
    def box_id(self):
        return self._box_id

    @box_id.setter
    def box_id(self, value):
        self._box_id = value
    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def target_appid(self):
        return self._target_appid

    @target_appid.setter
    def target_appid(self, value):
        self._target_appid = value


    def to_alipay_dict(self):
        params = dict()
        if self.box_id:
            if hasattr(self.box_id, 'to_alipay_dict'):
                params['box_id'] = self.box_id.to_alipay_dict()
            else:
                params['box_id'] = self.box_id
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.target_appid:
            if hasattr(self.target_appid, 'to_alipay_dict'):
                params['target_appid'] = self.target_appid.to_alipay_dict()
            else:
                params['target_appid'] = self.target_appid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchBoxBasicInfo()
        if 'box_id' in d:
            o.box_id = d['box_id']
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'name' in d:
            o.name = d['name']
        if 'status' in d:
            o.status = d['status']
        if 'target_appid' in d:
            o.target_appid = d['target_appid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateAuthenticateCampuscardCreateModel(object):

    def __init__(self):
        self._campus = None
        self._campus_no = None
        self._card_type = None
        self._cert_no = None
        self._cert_type = None
        self._expire_at = None
        self._ext_info = None
        self._gender = None
        self._isv_short_code = None
        self._organization = None
        self._school_name = None
        self._school_stdcode = None
        self._user_name = None

    @property
    def campus(self):
        return self._campus

    @campus.setter
    def campus(self, value):
        self._campus = value
    @property
    def campus_no(self):
        return self._campus_no

    @campus_no.setter
    def campus_no(self, value):
        self._campus_no = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def expire_at(self):
        return self._expire_at

    @expire_at.setter
    def expire_at(self, value):
        self._expire_at = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def isv_short_code(self):
        return self._isv_short_code

    @isv_short_code.setter
    def isv_short_code(self, value):
        self._isv_short_code = value
    @property
    def organization(self):
        return self._organization

    @organization.setter
    def organization(self, value):
        self._organization = value
    @property
    def school_name(self):
        return self._school_name

    @school_name.setter
    def school_name(self, value):
        self._school_name = value
    @property
    def school_stdcode(self):
        return self._school_stdcode

    @school_stdcode.setter
    def school_stdcode(self, value):
        self._school_stdcode = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.campus:
            if hasattr(self.campus, 'to_alipay_dict'):
                params['campus'] = self.campus.to_alipay_dict()
            else:
                params['campus'] = self.campus
        if self.campus_no:
            if hasattr(self.campus_no, 'to_alipay_dict'):
                params['campus_no'] = self.campus_no.to_alipay_dict()
            else:
                params['campus_no'] = self.campus_no
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.expire_at:
            if hasattr(self.expire_at, 'to_alipay_dict'):
                params['expire_at'] = self.expire_at.to_alipay_dict()
            else:
                params['expire_at'] = self.expire_at
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.isv_short_code:
            if hasattr(self.isv_short_code, 'to_alipay_dict'):
                params['isv_short_code'] = self.isv_short_code.to_alipay_dict()
            else:
                params['isv_short_code'] = self.isv_short_code
        if self.organization:
            if hasattr(self.organization, 'to_alipay_dict'):
                params['organization'] = self.organization.to_alipay_dict()
            else:
                params['organization'] = self.organization
        if self.school_name:
            if hasattr(self.school_name, 'to_alipay_dict'):
                params['school_name'] = self.school_name.to_alipay_dict()
            else:
                params['school_name'] = self.school_name
        if self.school_stdcode:
            if hasattr(self.school_stdcode, 'to_alipay_dict'):
                params['school_stdcode'] = self.school_stdcode.to_alipay_dict()
            else:
                params['school_stdcode'] = self.school_stdcode
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateAuthenticateCampuscardCreateModel()
        if 'campus' in d:
            o.campus = d['campus']
        if 'campus_no' in d:
            o.campus_no = d['campus_no']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'expire_at' in d:
            o.expire_at = d['expire_at']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'gender' in d:
            o.gender = d['gender']
        if 'isv_short_code' in d:
            o.isv_short_code = d['isv_short_code']
        if 'organization' in d:
            o.organization = d['organization']
        if 'school_name' in d:
            o.school_name = d['school_name']
        if 'school_stdcode' in d:
            o.school_stdcode = d['school_stdcode']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Hit import Hit


class GroupRecord(object):

    def __init__(self):
        self._count = None
        self._group_id = None
        self._group_name = None
        self._has_more = None
        self._hits = None
        self._more_link_name = None
        self._more_link_url = None
        self._total_count = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def group_name(self):
        return self._group_name

    @group_name.setter
    def group_name(self, value):
        self._group_name = value
    @property
    def has_more(self):
        return self._has_more

    @has_more.setter
    def has_more(self, value):
        self._has_more = value
    @property
    def hits(self):
        return self._hits

    @hits.setter
    def hits(self, value):
        if isinstance(value, list):
            self._hits = list()
            for i in value:
                if isinstance(i, Hit):
                    self._hits.append(i)
                else:
                    self._hits.append(Hit.from_alipay_dict(i))
    @property
    def more_link_name(self):
        return self._more_link_name

    @more_link_name.setter
    def more_link_name(self, value):
        self._more_link_name = value
    @property
    def more_link_url(self):
        return self._more_link_url

    @more_link_url.setter
    def more_link_url(self, value):
        self._more_link_url = value
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.group_name:
            if hasattr(self.group_name, 'to_alipay_dict'):
                params['group_name'] = self.group_name.to_alipay_dict()
            else:
                params['group_name'] = self.group_name
        if self.has_more:
            if hasattr(self.has_more, 'to_alipay_dict'):
                params['has_more'] = self.has_more.to_alipay_dict()
            else:
                params['has_more'] = self.has_more
        if self.hits:
            if isinstance(self.hits, list):
                for i in range(0, len(self.hits)):
                    element = self.hits[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.hits[i] = element.to_alipay_dict()
            if hasattr(self.hits, 'to_alipay_dict'):
                params['hits'] = self.hits.to_alipay_dict()
            else:
                params['hits'] = self.hits
        if self.more_link_name:
            if hasattr(self.more_link_name, 'to_alipay_dict'):
                params['more_link_name'] = self.more_link_name.to_alipay_dict()
            else:
                params['more_link_name'] = self.more_link_name
        if self.more_link_url:
            if hasattr(self.more_link_url, 'to_alipay_dict'):
                params['more_link_url'] = self.more_link_url.to_alipay_dict()
            else:
                params['more_link_url'] = self.more_link_url
        if self.total_count:
            if hasattr(self.total_count, 'to_alipay_dict'):
                params['total_count'] = self.total_count.to_alipay_dict()
            else:
                params['total_count'] = self.total_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GroupRecord()
        if 'count' in d:
            o.count = d['count']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'group_name' in d:
            o.group_name = d['group_name']
        if 'has_more' in d:
            o.has_more = d['has_more']
        if 'hits' in d:
            o.hits = d['hits']
        if 'more_link_name' in d:
            o.more_link_name = d['more_link_name']
        if 'more_link_url' in d:
            o.more_link_url = d['more_link_url']
        if 'total_count' in d:
            o.total_count = d['total_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerbaseinfoQueryModel(object):

    def __init__(self):
        self._app_sub_type = None
        self._inst_code = None
        self._mini_app_id = None
        self._mini_app_name = None

    @property
    def app_sub_type(self):
        return self._app_sub_type

    @app_sub_type.setter
    def app_sub_type(self, value):
        self._app_sub_type = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def mini_app_name(self):
        return self._mini_app_name

    @mini_app_name.setter
    def mini_app_name(self, value):
        self._mini_app_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_sub_type:
            if hasattr(self.app_sub_type, 'to_alipay_dict'):
                params['app_sub_type'] = self.app_sub_type.to_alipay_dict()
            else:
                params['app_sub_type'] = self.app_sub_type
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.mini_app_name:
            if hasattr(self.mini_app_name, 'to_alipay_dict'):
                params['mini_app_name'] = self.mini_app_name.to_alipay_dict()
            else:
                params['mini_app_name'] = self.mini_app_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerbaseinfoQueryModel()
        if 'app_sub_type' in d:
            o.app_sub_type = d['app_sub_type']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'mini_app_name' in d:
            o.mini_app_name = d['mini_app_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiRetailWmsGoodssafetyinventoryBatchqueryModel(object):

    def __init__(self):
        self._goods_codes = None
        self._warehouse_code = None

    @property
    def goods_codes(self):
        return self._goods_codes

    @goods_codes.setter
    def goods_codes(self, value):
        if isinstance(value, list):
            self._goods_codes = list()
            for i in value:
                self._goods_codes.append(i)
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_codes:
            if isinstance(self.goods_codes, list):
                for i in range(0, len(self.goods_codes)):
                    element = self.goods_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_codes[i] = element.to_alipay_dict()
            if hasattr(self.goods_codes, 'to_alipay_dict'):
                params['goods_codes'] = self.goods_codes.to_alipay_dict()
            else:
                params['goods_codes'] = self.goods_codes
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiRetailWmsGoodssafetyinventoryBatchqueryModel()
        if 'goods_codes' in d:
            o.goods_codes = d['goods_codes']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IotDeviceInfo import IotDeviceInfo


class AlipayMarketingShowwindowContentSyncModel(object):

    def __init__(self):
        self._device_info_list = None
        self._event_tag = None
        self._source = None

    @property
    def device_info_list(self):
        return self._device_info_list

    @device_info_list.setter
    def device_info_list(self, value):
        if isinstance(value, list):
            self._device_info_list = list()
            for i in value:
                if isinstance(i, IotDeviceInfo):
                    self._device_info_list.append(i)
                else:
                    self._device_info_list.append(IotDeviceInfo.from_alipay_dict(i))
    @property
    def event_tag(self):
        return self._event_tag

    @event_tag.setter
    def event_tag(self, value):
        self._event_tag = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_info_list:
            if isinstance(self.device_info_list, list):
                for i in range(0, len(self.device_info_list)):
                    element = self.device_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.device_info_list[i] = element.to_alipay_dict()
            if hasattr(self.device_info_list, 'to_alipay_dict'):
                params['device_info_list'] = self.device_info_list.to_alipay_dict()
            else:
                params['device_info_list'] = self.device_info_list
        if self.event_tag:
            if hasattr(self.event_tag, 'to_alipay_dict'):
                params['event_tag'] = self.event_tag.to_alipay_dict()
            else:
                params['event_tag'] = self.event_tag
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingShowwindowContentSyncModel()
        if 'device_info_list' in d:
            o.device_info_list = d['device_info_list']
        if 'event_tag' in d:
            o.event_tag = d['event_tag']
        if 'source' in d:
            o.source = d['source']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataAiserviceJunengLoanQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataAiserviceJunengLoanQueryResponse, self).__init__()
        self._biz_error_code = None
        self._hashed_cert_no = None
        self._request_uuid = None
        self._result = None

    @property
    def biz_error_code(self):
        return self._biz_error_code

    @biz_error_code.setter
    def biz_error_code(self, value):
        self._biz_error_code = value
    @property
    def hashed_cert_no(self):
        return self._hashed_cert_no

    @hashed_cert_no.setter
    def hashed_cert_no(self, value):
        self._hashed_cert_no = value
    @property
    def request_uuid(self):
        return self._request_uuid

    @request_uuid.setter
    def request_uuid(self, value):
        self._request_uuid = value
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataAiserviceJunengLoanQueryResponse, self).parse_response_content(response_content)
        if 'biz_error_code' in response:
            self.biz_error_code = response['biz_error_code']
        if 'hashed_cert_no' in response:
            self.hashed_cert_no = response['hashed_cert_no']
        if 'request_uuid' in response:
            self.request_uuid = response['request_uuid']
        if 'result' in response:
            self.result = response['result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MerchantActivityModifyVoucherInfo import MerchantActivityModifyVoucherInfo


class KoubeiMarketingCampaignItemMerchantactivityModifyModel(object):

    def __init__(self):
        self._activity_id = None
        self._external_callback_url = None
        self._gmt_end = None
        self._item_ids = None
        self._memo = None
        self._voucher_info = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def external_callback_url(self):
        return self._external_callback_url

    @external_callback_url.setter
    def external_callback_url(self, value):
        self._external_callback_url = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def item_ids(self):
        return self._item_ids

    @item_ids.setter
    def item_ids(self, value):
        if isinstance(value, list):
            self._item_ids = list()
            for i in value:
                self._item_ids.append(i)
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def voucher_info(self):
        return self._voucher_info

    @voucher_info.setter
    def voucher_info(self, value):
        if isinstance(value, MerchantActivityModifyVoucherInfo):
            self._voucher_info = value
        else:
            self._voucher_info = MerchantActivityModifyVoucherInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.external_callback_url:
            if hasattr(self.external_callback_url, 'to_alipay_dict'):
                params['external_callback_url'] = self.external_callback_url.to_alipay_dict()
            else:
                params['external_callback_url'] = self.external_callback_url
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.item_ids:
            if isinstance(self.item_ids, list):
                for i in range(0, len(self.item_ids)):
                    element = self.item_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_ids[i] = element.to_alipay_dict()
            if hasattr(self.item_ids, 'to_alipay_dict'):
                params['item_ids'] = self.item_ids.to_alipay_dict()
            else:
                params['item_ids'] = self.item_ids
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.voucher_info:
            if hasattr(self.voucher_info, 'to_alipay_dict'):
                params['voucher_info'] = self.voucher_info.to_alipay_dict()
            else:
                params['voucher_info'] = self.voucher_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignItemMerchantactivityModifyModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'external_callback_url' in d:
            o.external_callback_url = d['external_callback_url']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'item_ids' in d:
            o.item_ids = d['item_ids']
        if 'memo' in d:
            o.memo = d['memo']
        if 'voucher_info' in d:
            o.voucher_info = d['voucher_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PaidOuterCardCycleSellConfDTO import PaidOuterCardCycleSellConfDTO
from alipay.aop.api.domain.PaidOuterCardManageUrlConfDTO import PaidOuterCardManageUrlConfDTO
from alipay.aop.api.domain.PaidOuterCardSellingConfDTO import PaidOuterCardSellingConfDTO


class PaidOuterCardTemplateConfDTO(object):

    def __init__(self):
        self._cycle_selling_conf = None
        self._manage_url_conf = None
        self._open_selling_conf = None

    @property
    def cycle_selling_conf(self):
        return self._cycle_selling_conf

    @cycle_selling_conf.setter
    def cycle_selling_conf(self, value):
        if isinstance(value, PaidOuterCardCycleSellConfDTO):
            self._cycle_selling_conf = value
        else:
            self._cycle_selling_conf = PaidOuterCardCycleSellConfDTO.from_alipay_dict(value)
    @property
    def manage_url_conf(self):
        return self._manage_url_conf

    @manage_url_conf.setter
    def manage_url_conf(self, value):
        if isinstance(value, PaidOuterCardManageUrlConfDTO):
            self._manage_url_conf = value
        else:
            self._manage_url_conf = PaidOuterCardManageUrlConfDTO.from_alipay_dict(value)
    @property
    def open_selling_conf(self):
        return self._open_selling_conf

    @open_selling_conf.setter
    def open_selling_conf(self, value):
        if isinstance(value, PaidOuterCardSellingConfDTO):
            self._open_selling_conf = value
        else:
            self._open_selling_conf = PaidOuterCardSellingConfDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.cycle_selling_conf:
            if hasattr(self.cycle_selling_conf, 'to_alipay_dict'):
                params['cycle_selling_conf'] = self.cycle_selling_conf.to_alipay_dict()
            else:
                params['cycle_selling_conf'] = self.cycle_selling_conf
        if self.manage_url_conf:
            if hasattr(self.manage_url_conf, 'to_alipay_dict'):
                params['manage_url_conf'] = self.manage_url_conf.to_alipay_dict()
            else:
                params['manage_url_conf'] = self.manage_url_conf
        if self.open_selling_conf:
            if hasattr(self.open_selling_conf, 'to_alipay_dict'):
                params['open_selling_conf'] = self.open_selling_conf.to_alipay_dict()
            else:
                params['open_selling_conf'] = self.open_selling_conf
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaidOuterCardTemplateConfDTO()
        if 'cycle_selling_conf' in d:
            o.cycle_selling_conf = d['cycle_selling_conf']
        if 'manage_url_conf' in d:
            o.manage_url_conf = d['manage_url_conf']
        if 'open_selling_conf' in d:
            o.open_selling_conf = d['open_selling_conf']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CloudBusOdItem(object):

    def __init__(self):
        self._bus_od = None
        self._dest_geohash = None
        self._od = None
        self._week_od = None
        self._work_od = None

    @property
    def bus_od(self):
        return self._bus_od

    @bus_od.setter
    def bus_od(self, value):
        self._bus_od = value
    @property
    def dest_geohash(self):
        return self._dest_geohash

    @dest_geohash.setter
    def dest_geohash(self, value):
        self._dest_geohash = value
    @property
    def od(self):
        return self._od

    @od.setter
    def od(self, value):
        self._od = value
    @property
    def week_od(self):
        return self._week_od

    @week_od.setter
    def week_od(self, value):
        self._week_od = value
    @property
    def work_od(self):
        return self._work_od

    @work_od.setter
    def work_od(self, value):
        self._work_od = value


    def to_alipay_dict(self):
        params = dict()
        if self.bus_od:
            if hasattr(self.bus_od, 'to_alipay_dict'):
                params['bus_od'] = self.bus_od.to_alipay_dict()
            else:
                params['bus_od'] = self.bus_od
        if self.dest_geohash:
            if hasattr(self.dest_geohash, 'to_alipay_dict'):
                params['dest_geohash'] = self.dest_geohash.to_alipay_dict()
            else:
                params['dest_geohash'] = self.dest_geohash
        if self.od:
            if hasattr(self.od, 'to_alipay_dict'):
                params['od'] = self.od.to_alipay_dict()
            else:
                params['od'] = self.od
        if self.week_od:
            if hasattr(self.week_od, 'to_alipay_dict'):
                params['week_od'] = self.week_od.to_alipay_dict()
            else:
                params['week_od'] = self.week_od
        if self.work_od:
            if hasattr(self.work_od, 'to_alipay_dict'):
                params['work_od'] = self.work_od.to_alipay_dict()
            else:
                params['work_od'] = self.work_od
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CloudBusOdItem()
        if 'bus_od' in d:
            o.bus_od = d['bus_od']
        if 'dest_geohash' in d:
            o.dest_geohash = d['dest_geohash']
        if 'od' in d:
            o.od = d['od']
        if 'week_od' in d:
            o.week_od = d['week_od']
        if 'work_od' in d:
            o.work_od = d['work_od']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FaceMachineInfo(object):

    def __init__(self):
        self._camera_drive_ver = None
        self._camera_model = None
        self._camera_name = None
        self._camera_ver = None
        self._ext = None
        self._machine_code = None
        self._machine_model = None
        self._machine_ver = None

    @property
    def camera_drive_ver(self):
        return self._camera_drive_ver

    @camera_drive_ver.setter
    def camera_drive_ver(self, value):
        self._camera_drive_ver = value
    @property
    def camera_model(self):
        return self._camera_model

    @camera_model.setter
    def camera_model(self, value):
        self._camera_model = value
    @property
    def camera_name(self):
        return self._camera_name

    @camera_name.setter
    def camera_name(self, value):
        self._camera_name = value
    @property
    def camera_ver(self):
        return self._camera_ver

    @camera_ver.setter
    def camera_ver(self, value):
        self._camera_ver = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def machine_code(self):
        return self._machine_code

    @machine_code.setter
    def machine_code(self, value):
        self._machine_code = value
    @property
    def machine_model(self):
        return self._machine_model

    @machine_model.setter
    def machine_model(self, value):
        self._machine_model = value
    @property
    def machine_ver(self):
        return self._machine_ver

    @machine_ver.setter
    def machine_ver(self, value):
        self._machine_ver = value


    def to_alipay_dict(self):
        params = dict()
        if self.camera_drive_ver:
            if hasattr(self.camera_drive_ver, 'to_alipay_dict'):
                params['camera_drive_ver'] = self.camera_drive_ver.to_alipay_dict()
            else:
                params['camera_drive_ver'] = self.camera_drive_ver
        if self.camera_model:
            if hasattr(self.camera_model, 'to_alipay_dict'):
                params['camera_model'] = self.camera_model.to_alipay_dict()
            else:
                params['camera_model'] = self.camera_model
        if self.camera_name:
            if hasattr(self.camera_name, 'to_alipay_dict'):
                params['camera_name'] = self.camera_name.to_alipay_dict()
            else:
                params['camera_name'] = self.camera_name
        if self.camera_ver:
            if hasattr(self.camera_ver, 'to_alipay_dict'):
                params['camera_ver'] = self.camera_ver.to_alipay_dict()
            else:
                params['camera_ver'] = self.camera_ver
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.machine_code:
            if hasattr(self.machine_code, 'to_alipay_dict'):
                params['machine_code'] = self.machine_code.to_alipay_dict()
            else:
                params['machine_code'] = self.machine_code
        if self.machine_model:
            if hasattr(self.machine_model, 'to_alipay_dict'):
                params['machine_model'] = self.machine_model.to_alipay_dict()
            else:
                params['machine_model'] = self.machine_model
        if self.machine_ver:
            if hasattr(self.machine_ver, 'to_alipay_dict'):
                params['machine_ver'] = self.machine_ver.to_alipay_dict()
            else:
                params['machine_ver'] = self.machine_ver
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FaceMachineInfo()
        if 'camera_drive_ver' in d:
            o.camera_drive_ver = d['camera_drive_ver']
        if 'camera_model' in d:
            o.camera_model = d['camera_model']
        if 'camera_name' in d:
            o.camera_name = d['camera_name']
        if 'camera_ver' in d:
            o.camera_ver = d['camera_ver']
        if 'ext' in d:
            o.ext = d['ext']
        if 'machine_code' in d:
            o.machine_code = d['machine_code']
        if 'machine_model' in d:
            o.machine_model = d['machine_model']
        if 'machine_ver' in d:
            o.machine_ver = d['machine_ver']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntfortuneStockLinkfundQueryModel(object):

    def __init__(self):
        self._ret_limit = None
        self._symbol = None

    @property
    def ret_limit(self):
        return self._ret_limit

    @ret_limit.setter
    def ret_limit(self, value):
        self._ret_limit = value
    @property
    def symbol(self):
        return self._symbol

    @symbol.setter
    def symbol(self, value):
        self._symbol = value


    def to_alipay_dict(self):
        params = dict()
        if self.ret_limit:
            if hasattr(self.ret_limit, 'to_alipay_dict'):
                params['ret_limit'] = self.ret_limit.to_alipay_dict()
            else:
                params['ret_limit'] = self.ret_limit
        if self.symbol:
            if hasattr(self.symbol, 'to_alipay_dict'):
                params['symbol'] = self.symbol.to_alipay_dict()
            else:
                params['symbol'] = self.symbol
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneStockLinkfundQueryModel()
        if 'ret_limit' in d:
            o.ret_limit = d['ret_limit']
        if 'symbol' in d:
            o.symbol = d['symbol']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppAccountBalanceQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppAccountBalanceQueryResponse, self).__init__()
        self._account = None
        self._available_money = None
        self._balance = None
        self._date = None
        self._freeze_money = None
        self._request_time = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def available_money(self):
        return self._available_money

    @available_money.setter
    def available_money(self, value):
        self._available_money = value
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def freeze_money(self):
        return self._freeze_money

    @freeze_money.setter
    def freeze_money(self, value):
        self._freeze_money = value
    @property
    def request_time(self):
        return self._request_time

    @request_time.setter
    def request_time(self, value):
        self._request_time = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppAccountBalanceQueryResponse, self).parse_response_content(response_content)
        if 'account' in response:
            self.account = response['account']
        if 'available_money' in response:
            self.available_money = response['available_money']
        if 'balance' in response:
            self.balance = response['balance']
        if 'date' in response:
            self.date = response['date']
        if 'freeze_money' in response:
            self.freeze_money = response['freeze_money']
        if 'request_time' in response:
            self.request_time = response['request_time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CreditBankCertificateExperience import CreditBankCertificateExperience


class AlipayCommerceEducateCreditbankCertificateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateCreditbankCertificateQueryResponse, self).__init__()
        self._certificates = None

    @property
    def certificates(self):
        return self._certificates

    @certificates.setter
    def certificates(self, value):
        if isinstance(value, list):
            self._certificates = list()
            for i in value:
                if isinstance(i, CreditBankCertificateExperience):
                    self._certificates.append(i)
                else:
                    self._certificates.append(CreditBankCertificateExperience.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateCreditbankCertificateQueryResponse, self).parse_response_content(response_content)
        if 'certificates' in response:
            self.certificates = response['certificates']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsMktCouponCmpgnBaseDTO(object):

    def __init__(self):
        self._campaign_id = None
        self._coupon_type = None
        self._coupon_upper_value = None
        self._coupon_value = None

    @property
    def campaign_id(self):
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, value):
        self._campaign_id = value
    @property
    def coupon_type(self):
        return self._coupon_type

    @coupon_type.setter
    def coupon_type(self, value):
        self._coupon_type = value
    @property
    def coupon_upper_value(self):
        return self._coupon_upper_value

    @coupon_upper_value.setter
    def coupon_upper_value(self, value):
        self._coupon_upper_value = value
    @property
    def coupon_value(self):
        return self._coupon_value

    @coupon_value.setter
    def coupon_value(self, value):
        self._coupon_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.campaign_id:
            if hasattr(self.campaign_id, 'to_alipay_dict'):
                params['campaign_id'] = self.campaign_id.to_alipay_dict()
            else:
                params['campaign_id'] = self.campaign_id
        if self.coupon_type:
            if hasattr(self.coupon_type, 'to_alipay_dict'):
                params['coupon_type'] = self.coupon_type.to_alipay_dict()
            else:
                params['coupon_type'] = self.coupon_type
        if self.coupon_upper_value:
            if hasattr(self.coupon_upper_value, 'to_alipay_dict'):
                params['coupon_upper_value'] = self.coupon_upper_value.to_alipay_dict()
            else:
                params['coupon_upper_value'] = self.coupon_upper_value
        if self.coupon_value:
            if hasattr(self.coupon_value, 'to_alipay_dict'):
                params['coupon_value'] = self.coupon_value.to_alipay_dict()
            else:
                params['coupon_value'] = self.coupon_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsMktCouponCmpgnBaseDTO()
        if 'campaign_id' in d:
            o.campaign_id = d['campaign_id']
        if 'coupon_type' in d:
            o.coupon_type = d['coupon_type']
        if 'coupon_upper_value' in d:
            o.coupon_upper_value = d['coupon_upper_value']
        if 'coupon_value' in d:
            o.coupon_value = d['coupon_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicInfoModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicInfoModifyResponse, self).__init__()
        self._audit_desc = None
        self._audit_status = None

    @property
    def audit_desc(self):
        return self._audit_desc

    @audit_desc.setter
    def audit_desc(self, value):
        self._audit_desc = value
    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicInfoModifyResponse, self).parse_response_content(response_content)
        if 'audit_desc' in response:
            self.audit_desc = response['audit_desc']
        if 'audit_status' in response:
            self.audit_status = response['audit_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SearchBaseItems import SearchBaseItems
from alipay.aop.api.domain.SearchBrandItems import SearchBrandItems
from alipay.aop.api.domain.SearchServiceItems import SearchServiceItems


class SearchOrderCreateRequest(object):

    def __init__(self):
        self._access_mode = None
        self._access_type = None
        self._action = None
        self._app_name = None
        self._appid = None
        self._base_items = None
        self._biz_id = None
        self._brand_down_grade = None
        self._brand_items = None
        self._create_type = None
        self._data_key = None
        self._descprise = None
        self._is_draft = None
        self._key_words = None
        self._online_time = None
        self._order_id = None
        self._ref_apply_id = None
        self._scene = None
        self._scene_name = None
        self._service_code = None
        self._service_items = None
        self._spec_code = None
        self._sub_service_code = None
        self._template_id = None
        self._template_type = None

    @property
    def access_mode(self):
        return self._access_mode

    @access_mode.setter
    def access_mode(self, value):
        self._access_mode = value
    @property
    def access_type(self):
        return self._access_type

    @access_type.setter
    def access_type(self, value):
        self._access_type = value
    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def appid(self):
        return self._appid

    @appid.setter
    def appid(self, value):
        self._appid = value
    @property
    def base_items(self):
        return self._base_items

    @base_items.setter
    def base_items(self, value):
        if isinstance(value, SearchBaseItems):
            self._base_items = value
        else:
            self._base_items = SearchBaseItems.from_alipay_dict(value)
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def brand_down_grade(self):
        return self._brand_down_grade

    @brand_down_grade.setter
    def brand_down_grade(self, value):
        self._brand_down_grade = value
    @property
    def brand_items(self):
        return self._brand_items

    @brand_items.setter
    def brand_items(self, value):
        if isinstance(value, SearchBrandItems):
            self._brand_items = value
        else:
            self._brand_items = SearchBrandItems.from_alipay_dict(value)
    @property
    def create_type(self):
        return self._create_type

    @create_type.setter
    def create_type(self, value):
        self._create_type = value
    @property
    def data_key(self):
        return self._data_key

    @data_key.setter
    def data_key(self, value):
        self._data_key = value
    @property
    def descprise(self):
        return self._descprise

    @descprise.setter
    def descprise(self, value):
        self._descprise = value
    @property
    def is_draft(self):
        return self._is_draft

    @is_draft.setter
    def is_draft(self, value):
        self._is_draft = value
    @property
    def key_words(self):
        return self._key_words

    @key_words.setter
    def key_words(self, value):
        self._key_words = value
    @property
    def online_time(self):
        return self._online_time

    @online_time.setter
    def online_time(self, value):
        self._online_time = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def ref_apply_id(self):
        return self._ref_apply_id

    @ref_apply_id.setter
    def ref_apply_id(self, value):
        self._ref_apply_id = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def scene_name(self):
        return self._scene_name

    @scene_name.setter
    def scene_name(self, value):
        self._scene_name = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_items(self):
        return self._service_items

    @service_items.setter
    def service_items(self, value):
        if isinstance(value, SearchServiceItems):
            self._service_items = value
        else:
            self._service_items = SearchServiceItems.from_alipay_dict(value)
    @property
    def spec_code(self):
        return self._spec_code

    @spec_code.setter
    def spec_code(self, value):
        self._spec_code = value
    @property
    def sub_service_code(self):
        return self._sub_service_code

    @sub_service_code.setter
    def sub_service_code(self, value):
        self._sub_service_code = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def template_type(self):
        return self._template_type

    @template_type.setter
    def template_type(self, value):
        self._template_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.access_mode:
            if hasattr(self.access_mode, 'to_alipay_dict'):
                params['access_mode'] = self.access_mode.to_alipay_dict()
            else:
                params['access_mode'] = self.access_mode
        if self.access_type:
            if hasattr(self.access_type, 'to_alipay_dict'):
                params['access_type'] = self.access_type.to_alipay_dict()
            else:
                params['access_type'] = self.access_type
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.appid:
            if hasattr(self.appid, 'to_alipay_dict'):
                params['appid'] = self.appid.to_alipay_dict()
            else:
                params['appid'] = self.appid
        if self.base_items:
            if hasattr(self.base_items, 'to_alipay_dict'):
                params['base_items'] = self.base_items.to_alipay_dict()
            else:
                params['base_items'] = self.base_items
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.brand_down_grade:
            if hasattr(self.brand_down_grade, 'to_alipay_dict'):
                params['brand_down_grade'] = self.brand_down_grade.to_alipay_dict()
            else:
                params['brand_down_grade'] = self.brand_down_grade
        if self.brand_items:
            if hasattr(self.brand_items, 'to_alipay_dict'):
                params['brand_items'] = self.brand_items.to_alipay_dict()
            else:
                params['brand_items'] = self.brand_items
        if self.create_type:
            if hasattr(self.create_type, 'to_alipay_dict'):
                params['create_type'] = self.create_type.to_alipay_dict()
            else:
                params['create_type'] = self.create_type
        if self.data_key:
            if hasattr(self.data_key, 'to_alipay_dict'):
                params['data_key'] = self.data_key.to_alipay_dict()
            else:
                params['data_key'] = self.data_key
        if self.descprise:
            if hasattr(self.descprise, 'to_alipay_dict'):
                params['descprise'] = self.descprise.to_alipay_dict()
            else:
                params['descprise'] = self.descprise
        if self.is_draft:
            if hasattr(self.is_draft, 'to_alipay_dict'):
                params['is_draft'] = self.is_draft.to_alipay_dict()
            else:
                params['is_draft'] = self.is_draft
        if self.key_words:
            if hasattr(self.key_words, 'to_alipay_dict'):
                params['key_words'] = self.key_words.to_alipay_dict()
            else:
                params['key_words'] = self.key_words
        if self.online_time:
            if hasattr(self.online_time, 'to_alipay_dict'):
                params['online_time'] = self.online_time.to_alipay_dict()
            else:
                params['online_time'] = self.online_time
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.ref_apply_id:
            if hasattr(self.ref_apply_id, 'to_alipay_dict'):
                params['ref_apply_id'] = self.ref_apply_id.to_alipay_dict()
            else:
                params['ref_apply_id'] = self.ref_apply_id
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.scene_name:
            if hasattr(self.scene_name, 'to_alipay_dict'):
                params['scene_name'] = self.scene_name.to_alipay_dict()
            else:
                params['scene_name'] = self.scene_name
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.service_items:
            if hasattr(self.service_items, 'to_alipay_dict'):
                params['service_items'] = self.service_items.to_alipay_dict()
            else:
                params['service_items'] = self.service_items
        if self.spec_code:
            if hasattr(self.spec_code, 'to_alipay_dict'):
                params['spec_code'] = self.spec_code.to_alipay_dict()
            else:
                params['spec_code'] = self.spec_code
        if self.sub_service_code:
            if hasattr(self.sub_service_code, 'to_alipay_dict'):
                params['sub_service_code'] = self.sub_service_code.to_alipay_dict()
            else:
                params['sub_service_code'] = self.sub_service_code
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.template_type:
            if hasattr(self.template_type, 'to_alipay_dict'):
                params['template_type'] = self.template_type.to_alipay_dict()
            else:
                params['template_type'] = self.template_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchOrderCreateRequest()
        if 'access_mode' in d:
            o.access_mode = d['access_mode']
        if 'access_type' in d:
            o.access_type = d['access_type']
        if 'action' in d:
            o.action = d['action']
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'appid' in d:
            o.appid = d['appid']
        if 'base_items' in d:
            o.base_items = d['base_items']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'brand_down_grade' in d:
            o.brand_down_grade = d['brand_down_grade']
        if 'brand_items' in d:
            o.brand_items = d['brand_items']
        if 'create_type' in d:
            o.create_type = d['create_type']
        if 'data_key' in d:
            o.data_key = d['data_key']
        if 'descprise' in d:
            o.descprise = d['descprise']
        if 'is_draft' in d:
            o.is_draft = d['is_draft']
        if 'key_words' in d:
            o.key_words = d['key_words']
        if 'online_time' in d:
            o.online_time = d['online_time']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'ref_apply_id' in d:
            o.ref_apply_id = d['ref_apply_id']
        if 'scene' in d:
            o.scene = d['scene']
        if 'scene_name' in d:
            o.scene_name = d['scene_name']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'service_items' in d:
            o.service_items = d['service_items']
        if 'spec_code' in d:
            o.spec_code = d['spec_code']
        if 'sub_service_code' in d:
            o.sub_service_code = d['sub_service_code']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'template_type' in d:
            o.template_type = d['template_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsMarketingLifeAccessQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsMarketingLifeAccessQueryResponse, self).__init__()
        self._access = None

    @property
    def access(self):
        return self._access

    @access.setter
    def access(self, value):
        self._access = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsMarketingLifeAccessQueryResponse, self).parse_response_content(response_content)
        if 'access' in response:
            self.access = response['access']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenOperationBizfeeAftechUnsubscribeModel(object):

    def __init__(self):
        self._app_name = None
        self._ar_no = None
        self._gmt_service = None
        self._gmt_stop = None
        self._out_biz_no = None
        self._return_fee_amount = None
        self._return_fee_currency = None
        self._tnt_inst_id = None
        self._used_service_amount = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def gmt_service(self):
        return self._gmt_service

    @gmt_service.setter
    def gmt_service(self, value):
        self._gmt_service = value
    @property
    def gmt_stop(self):
        return self._gmt_stop

    @gmt_stop.setter
    def gmt_stop(self, value):
        self._gmt_stop = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def return_fee_amount(self):
        return self._return_fee_amount

    @return_fee_amount.setter
    def return_fee_amount(self, value):
        self._return_fee_amount = value
    @property
    def return_fee_currency(self):
        return self._return_fee_currency

    @return_fee_currency.setter
    def return_fee_currency(self, value):
        self._return_fee_currency = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def used_service_amount(self):
        return self._used_service_amount

    @used_service_amount.setter
    def used_service_amount(self, value):
        self._used_service_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.ar_no:
            if hasattr(self.ar_no, 'to_alipay_dict'):
                params['ar_no'] = self.ar_no.to_alipay_dict()
            else:
                params['ar_no'] = self.ar_no
        if self.gmt_service:
            if hasattr(self.gmt_service, 'to_alipay_dict'):
                params['gmt_service'] = self.gmt_service.to_alipay_dict()
            else:
                params['gmt_service'] = self.gmt_service
        if self.gmt_stop:
            if hasattr(self.gmt_stop, 'to_alipay_dict'):
                params['gmt_stop'] = self.gmt_stop.to_alipay_dict()
            else:
                params['gmt_stop'] = self.gmt_stop
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.return_fee_amount:
            if hasattr(self.return_fee_amount, 'to_alipay_dict'):
                params['return_fee_amount'] = self.return_fee_amount.to_alipay_dict()
            else:
                params['return_fee_amount'] = self.return_fee_amount
        if self.return_fee_currency:
            if hasattr(self.return_fee_currency, 'to_alipay_dict'):
                params['return_fee_currency'] = self.return_fee_currency.to_alipay_dict()
            else:
                params['return_fee_currency'] = self.return_fee_currency
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        if self.used_service_amount:
            if hasattr(self.used_service_amount, 'to_alipay_dict'):
                params['used_service_amount'] = self.used_service_amount.to_alipay_dict()
            else:
                params['used_service_amount'] = self.used_service_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenOperationBizfeeAftechUnsubscribeModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'ar_no' in d:
            o.ar_no = d['ar_no']
        if 'gmt_service' in d:
            o.gmt_service = d['gmt_service']
        if 'gmt_stop' in d:
            o.gmt_stop = d['gmt_stop']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'return_fee_amount' in d:
            o.return_fee_amount = d['return_fee_amount']
        if 'return_fee_currency' in d:
            o.return_fee_currency = d['return_fee_currency']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        if 'used_service_amount' in d:
            o.used_service_amount = d['used_service_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ParamModel(object):

    def __init__(self):
        self._cabinet_enabled = None
        self._carry_rule = None
        self._dining_mode = None
        self._kds_display_mode = None
        self._kds_enabled = None
        self._kds_voice_call_enabled = None
        self._multi_cabinet_per_order_allowed = None
        self._open_ele = None
        self._reason_flag = None
        self._shop_id = None
        self._shop_name = None
        self._table_flag = None
        self._tail_number_rule = None
        self._takeout_auto_receipt = None

    @property
    def cabinet_enabled(self):
        return self._cabinet_enabled

    @cabinet_enabled.setter
    def cabinet_enabled(self, value):
        self._cabinet_enabled = value
    @property
    def carry_rule(self):
        return self._carry_rule

    @carry_rule.setter
    def carry_rule(self, value):
        self._carry_rule = value
    @property
    def dining_mode(self):
        return self._dining_mode

    @dining_mode.setter
    def dining_mode(self, value):
        self._dining_mode = value
    @property
    def kds_display_mode(self):
        return self._kds_display_mode

    @kds_display_mode.setter
    def kds_display_mode(self, value):
        self._kds_display_mode = value
    @property
    def kds_enabled(self):
        return self._kds_enabled

    @kds_enabled.setter
    def kds_enabled(self, value):
        self._kds_enabled = value
    @property
    def kds_voice_call_enabled(self):
        return self._kds_voice_call_enabled

    @kds_voice_call_enabled.setter
    def kds_voice_call_enabled(self, value):
        self._kds_voice_call_enabled = value
    @property
    def multi_cabinet_per_order_allowed(self):
        return self._multi_cabinet_per_order_allowed

    @multi_cabinet_per_order_allowed.setter
    def multi_cabinet_per_order_allowed(self, value):
        self._multi_cabinet_per_order_allowed = value
    @property
    def open_ele(self):
        return self._open_ele

    @open_ele.setter
    def open_ele(self, value):
        self._open_ele = value
    @property
    def reason_flag(self):
        return self._reason_flag

    @reason_flag.setter
    def reason_flag(self, value):
        self._reason_flag = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def table_flag(self):
        return self._table_flag

    @table_flag.setter
    def table_flag(self, value):
        self._table_flag = value
    @property
    def tail_number_rule(self):
        return self._tail_number_rule

    @tail_number_rule.setter
    def tail_number_rule(self, value):
        self._tail_number_rule = value
    @property
    def takeout_auto_receipt(self):
        return self._takeout_auto_receipt

    @takeout_auto_receipt.setter
    def takeout_auto_receipt(self, value):
        self._takeout_auto_receipt = value


    def to_alipay_dict(self):
        params = dict()
        if self.cabinet_enabled:
            if hasattr(self.cabinet_enabled, 'to_alipay_dict'):
                params['cabinet_enabled'] = self.cabinet_enabled.to_alipay_dict()
            else:
                params['cabinet_enabled'] = self.cabinet_enabled
        if self.carry_rule:
            if hasattr(self.carry_rule, 'to_alipay_dict'):
                params['carry_rule'] = self.carry_rule.to_alipay_dict()
            else:
                params['carry_rule'] = self.carry_rule
        if self.dining_mode:
            if hasattr(self.dining_mode, 'to_alipay_dict'):
                params['dining_mode'] = self.dining_mode.to_alipay_dict()
            else:
                params['dining_mode'] = self.dining_mode
        if self.kds_display_mode:
            if hasattr(self.kds_display_mode, 'to_alipay_dict'):
                params['kds_display_mode'] = self.kds_display_mode.to_alipay_dict()
            else:
                params['kds_display_mode'] = self.kds_display_mode
        if self.kds_enabled:
            if hasattr(self.kds_enabled, 'to_alipay_dict'):
                params['kds_enabled'] = self.kds_enabled.to_alipay_dict()
            else:
                params['kds_enabled'] = self.kds_enabled
        if self.kds_voice_call_enabled:
            if hasattr(self.kds_voice_call_enabled, 'to_alipay_dict'):
                params['kds_voice_call_enabled'] = self.kds_voice_call_enabled.to_alipay_dict()
            else:
                params['kds_voice_call_enabled'] = self.kds_voice_call_enabled
        if self.multi_cabinet_per_order_allowed:
            if hasattr(self.multi_cabinet_per_order_allowed, 'to_alipay_dict'):
                params['multi_cabinet_per_order_allowed'] = self.multi_cabinet_per_order_allowed.to_alipay_dict()
            else:
                params['multi_cabinet_per_order_allowed'] = self.multi_cabinet_per_order_allowed
        if self.open_ele:
            if hasattr(self.open_ele, 'to_alipay_dict'):
                params['open_ele'] = self.open_ele.to_alipay_dict()
            else:
                params['open_ele'] = self.open_ele
        if self.reason_flag:
            if hasattr(self.reason_flag, 'to_alipay_dict'):
                params['reason_flag'] = self.reason_flag.to_alipay_dict()
            else:
                params['reason_flag'] = self.reason_flag
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.table_flag:
            if hasattr(self.table_flag, 'to_alipay_dict'):
                params['table_flag'] = self.table_flag.to_alipay_dict()
            else:
                params['table_flag'] = self.table_flag
        if self.tail_number_rule:
            if hasattr(self.tail_number_rule, 'to_alipay_dict'):
                params['tail_number_rule'] = self.tail_number_rule.to_alipay_dict()
            else:
                params['tail_number_rule'] = self.tail_number_rule
        if self.takeout_auto_receipt:
            if hasattr(self.takeout_auto_receipt, 'to_alipay_dict'):
                params['takeout_auto_receipt'] = self.takeout_auto_receipt.to_alipay_dict()
            else:
                params['takeout_auto_receipt'] = self.takeout_auto_receipt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ParamModel()
        if 'cabinet_enabled' in d:
            o.cabinet_enabled = d['cabinet_enabled']
        if 'carry_rule' in d:
            o.carry_rule = d['carry_rule']
        if 'dining_mode' in d:
            o.dining_mode = d['dining_mode']
        if 'kds_display_mode' in d:
            o.kds_display_mode = d['kds_display_mode']
        if 'kds_enabled' in d:
            o.kds_enabled = d['kds_enabled']
        if 'kds_voice_call_enabled' in d:
            o.kds_voice_call_enabled = d['kds_voice_call_enabled']
        if 'multi_cabinet_per_order_allowed' in d:
            o.multi_cabinet_per_order_allowed = d['multi_cabinet_per_order_allowed']
        if 'open_ele' in d:
            o.open_ele = d['open_ele']
        if 'reason_flag' in d:
            o.reason_flag = d['reason_flag']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'table_flag' in d:
            o.table_flag = d['table_flag']
        if 'tail_number_rule' in d:
            o.tail_number_rule = d['tail_number_rule']
        if 'takeout_auto_receipt' in d:
            o.takeout_auto_receipt = d['takeout_auto_receipt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCcmRoleGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCcmRoleGetResponse, self).__init__()
        self._ccs_instance_id = None
        self._create_time = None
        self._creator_id = None
        self._description = None
        self._function_ids = None
        self._id = None
        self._name = None
        self._update_time = None
        self._updater_id = None

    @property
    def ccs_instance_id(self):
        return self._ccs_instance_id

    @ccs_instance_id.setter
    def ccs_instance_id(self, value):
        self._ccs_instance_id = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def function_ids(self):
        return self._function_ids

    @function_ids.setter
    def function_ids(self, value):
        if isinstance(value, list):
            self._function_ids = list()
            for i in value:
                self._function_ids.append(i)
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def update_time(self):
        return self._update_time

    @update_time.setter
    def update_time(self, value):
        self._update_time = value
    @property
    def updater_id(self):
        return self._updater_id

    @updater_id.setter
    def updater_id(self, value):
        self._updater_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCcmRoleGetResponse, self).parse_response_content(response_content)
        if 'ccs_instance_id' in response:
            self.ccs_instance_id = response['ccs_instance_id']
        if 'create_time' in response:
            self.create_time = response['create_time']
        if 'creator_id' in response:
            self.creator_id = response['creator_id']
        if 'description' in response:
            self.description = response['description']
        if 'function_ids' in response:
            self.function_ids = response['function_ids']
        if 'id' in response:
            self.id = response['id']
        if 'name' in response:
            self.name = response['name']
        if 'update_time' in response:
            self.update_time = response['update_time']
        if 'updater_id' in response:
            self.updater_id = response['updater_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IotVspOrgUserAddUserInfoRequest(object):

    def __init__(self):
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._ext = None
        self._phone = None

    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IotVspOrgUserAddUserInfoRequest()
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'ext' in d:
            o.ext = d['ext']
        if 'phone' in d:
            o.phone = d['phone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GbApplyRequest import GbApplyRequest


class AlipayBossFncAntbudgetGroupbudgetApplyModel(object):

    def __init__(self):
        self._batch_id = None
        self._group_budget_apply_request_list = None
        self._ns = None

    @property
    def batch_id(self):
        return self._batch_id

    @batch_id.setter
    def batch_id(self, value):
        self._batch_id = value
    @property
    def group_budget_apply_request_list(self):
        return self._group_budget_apply_request_list

    @group_budget_apply_request_list.setter
    def group_budget_apply_request_list(self, value):
        if isinstance(value, list):
            self._group_budget_apply_request_list = list()
            for i in value:
                if isinstance(i, GbApplyRequest):
                    self._group_budget_apply_request_list.append(i)
                else:
                    self._group_budget_apply_request_list.append(GbApplyRequest.from_alipay_dict(i))
    @property
    def ns(self):
        return self._ns

    @ns.setter
    def ns(self, value):
        self._ns = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_id:
            if hasattr(self.batch_id, 'to_alipay_dict'):
                params['batch_id'] = self.batch_id.to_alipay_dict()
            else:
                params['batch_id'] = self.batch_id
        if self.group_budget_apply_request_list:
            if isinstance(self.group_budget_apply_request_list, list):
                for i in range(0, len(self.group_budget_apply_request_list)):
                    element = self.group_budget_apply_request_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.group_budget_apply_request_list[i] = element.to_alipay_dict()
            if hasattr(self.group_budget_apply_request_list, 'to_alipay_dict'):
                params['group_budget_apply_request_list'] = self.group_budget_apply_request_list.to_alipay_dict()
            else:
                params['group_budget_apply_request_list'] = self.group_budget_apply_request_list
        if self.ns:
            if hasattr(self.ns, 'to_alipay_dict'):
                params['ns'] = self.ns.to_alipay_dict()
            else:
                params['ns'] = self.ns
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncAntbudgetGroupbudgetApplyModel()
        if 'batch_id' in d:
            o.batch_id = d['batch_id']
        if 'group_budget_apply_request_list' in d:
            o.group_budget_apply_request_list = d['group_budget_apply_request_list']
        if 'ns' in d:
            o.ns = d['ns']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateAuthenticateCampuscardModifyModel(object):

    def __init__(self):
        self._campus = None
        self._campus_no = None
        self._card_no = None
        self._card_status = None
        self._card_type = None
        self._cert_no = None
        self._cert_type = None
        self._chip_no = None
        self._email = None
        self._expire_at = None
        self._ext_info = None
        self._gender = None
        self._image_base_64 = None
        self._image_date = None
        self._isv_short_code = None
        self._mobile_no = None
        self._name = None
        self._organization = None
        self._school_name = None
        self._school_stdcode = None
        self._short_code = None

    @property
    def campus(self):
        return self._campus

    @campus.setter
    def campus(self, value):
        self._campus = value
    @property
    def campus_no(self):
        return self._campus_no

    @campus_no.setter
    def campus_no(self, value):
        self._campus_no = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def card_status(self):
        return self._card_status

    @card_status.setter
    def card_status(self, value):
        self._card_status = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def chip_no(self):
        return self._chip_no

    @chip_no.setter
    def chip_no(self, value):
        self._chip_no = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def expire_at(self):
        return self._expire_at

    @expire_at.setter
    def expire_at(self, value):
        self._expire_at = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def image_base_64(self):
        return self._image_base_64

    @image_base_64.setter
    def image_base_64(self, value):
        self._image_base_64 = value
    @property
    def image_date(self):
        return self._image_date

    @image_date.setter
    def image_date(self, value):
        self._image_date = value
    @property
    def isv_short_code(self):
        return self._isv_short_code

    @isv_short_code.setter
    def isv_short_code(self, value):
        self._isv_short_code = value
    @property
    def mobile_no(self):
        return self._mobile_no

    @mobile_no.setter
    def mobile_no(self, value):
        self._mobile_no = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def organization(self):
        return self._organization

    @organization.setter
    def organization(self, value):
        self._organization = value
    @property
    def school_name(self):
        return self._school_name

    @school_name.setter
    def school_name(self, value):
        self._school_name = value
    @property
    def school_stdcode(self):
        return self._school_stdcode

    @school_stdcode.setter
    def school_stdcode(self, value):
        self._school_stdcode = value
    @property
    def short_code(self):
        return self._short_code

    @short_code.setter
    def short_code(self, value):
        self._short_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.campus:
            if hasattr(self.campus, 'to_alipay_dict'):
                params['campus'] = self.campus.to_alipay_dict()
            else:
                params['campus'] = self.campus
        if self.campus_no:
            if hasattr(self.campus_no, 'to_alipay_dict'):
                params['campus_no'] = self.campus_no.to_alipay_dict()
            else:
                params['campus_no'] = self.campus_no
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.card_status:
            if hasattr(self.card_status, 'to_alipay_dict'):
                params['card_status'] = self.card_status.to_alipay_dict()
            else:
                params['card_status'] = self.card_status
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.chip_no:
            if hasattr(self.chip_no, 'to_alipay_dict'):
                params['chip_no'] = self.chip_no.to_alipay_dict()
            else:
                params['chip_no'] = self.chip_no
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.expire_at:
            if hasattr(self.expire_at, 'to_alipay_dict'):
                params['expire_at'] = self.expire_at.to_alipay_dict()
            else:
                params['expire_at'] = self.expire_at
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.image_base_64:
            if hasattr(self.image_base_64, 'to_alipay_dict'):
                params['image_base_64'] = self.image_base_64.to_alipay_dict()
            else:
                params['image_base_64'] = self.image_base_64
        if self.image_date:
            if hasattr(self.image_date, 'to_alipay_dict'):
                params['image_date'] = self.image_date.to_alipay_dict()
            else:
                params['image_date'] = self.image_date
        if self.isv_short_code:
            if hasattr(self.isv_short_code, 'to_alipay_dict'):
                params['isv_short_code'] = self.isv_short_code.to_alipay_dict()
            else:
                params['isv_short_code'] = self.isv_short_code
        if self.mobile_no:
            if hasattr(self.mobile_no, 'to_alipay_dict'):
                params['mobile_no'] = self.mobile_no.to_alipay_dict()
            else:
                params['mobile_no'] = self.mobile_no
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.organization:
            if hasattr(self.organization, 'to_alipay_dict'):
                params['organization'] = self.organization.to_alipay_dict()
            else:
                params['organization'] = self.organization
        if self.school_name:
            if hasattr(self.school_name, 'to_alipay_dict'):
                params['school_name'] = self.school_name.to_alipay_dict()
            else:
                params['school_name'] = self.school_name
        if self.school_stdcode:
            if hasattr(self.school_stdcode, 'to_alipay_dict'):
                params['school_stdcode'] = self.school_stdcode.to_alipay_dict()
            else:
                params['school_stdcode'] = self.school_stdcode
        if self.short_code:
            if hasattr(self.short_code, 'to_alipay_dict'):
                params['short_code'] = self.short_code.to_alipay_dict()
            else:
                params['short_code'] = self.short_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateAuthenticateCampuscardModifyModel()
        if 'campus' in d:
            o.campus = d['campus']
        if 'campus_no' in d:
            o.campus_no = d['campus_no']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'card_status' in d:
            o.card_status = d['card_status']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'chip_no' in d:
            o.chip_no = d['chip_no']
        if 'email' in d:
            o.email = d['email']
        if 'expire_at' in d:
            o.expire_at = d['expire_at']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'gender' in d:
            o.gender = d['gender']
        if 'image_base_64' in d:
            o.image_base_64 = d['image_base_64']
        if 'image_date' in d:
            o.image_date = d['image_date']
        if 'isv_short_code' in d:
            o.isv_short_code = d['isv_short_code']
        if 'mobile_no' in d:
            o.mobile_no = d['mobile_no']
        if 'name' in d:
            o.name = d['name']
        if 'organization' in d:
            o.organization = d['organization']
        if 'school_name' in d:
            o.school_name = d['school_name']
        if 'school_stdcode' in d:
            o.school_stdcode = d['school_stdcode']
        if 'short_code' in d:
            o.short_code = d['short_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.HbMerchantInfo import HbMerchantInfo


class AlipayPcreditHuabeiMerchantActivityModifyModel(object):

    def __init__(self):
        self._activity_name = None
        self._aggr_id = None
        self._amount_budget = None
        self._budget_warning_mail_list = None
        self._budget_warning_mobile_list = None
        self._budget_warning_money = None
        self._end_time = None
        self._fund_type = None
        self._install_num_list = None
        self._isv_id = None
        self._max_money_limit = None
        self._merchant_info = None
        self._min_money_limit = None
        self._out_request_no = None
        self._start_time = None
        self._subsidy_scope = None

    @property
    def activity_name(self):
        return self._activity_name

    @activity_name.setter
    def activity_name(self, value):
        self._activity_name = value
    @property
    def aggr_id(self):
        return self._aggr_id

    @aggr_id.setter
    def aggr_id(self, value):
        self._aggr_id = value
    @property
    def amount_budget(self):
        return self._amount_budget

    @amount_budget.setter
    def amount_budget(self, value):
        self._amount_budget = value
    @property
    def budget_warning_mail_list(self):
        return self._budget_warning_mail_list

    @budget_warning_mail_list.setter
    def budget_warning_mail_list(self, value):
        self._budget_warning_mail_list = value
    @property
    def budget_warning_mobile_list(self):
        return self._budget_warning_mobile_list

    @budget_warning_mobile_list.setter
    def budget_warning_mobile_list(self, value):
        self._budget_warning_mobile_list = value
    @property
    def budget_warning_money(self):
        return self._budget_warning_money

    @budget_warning_money.setter
    def budget_warning_money(self, value):
        self._budget_warning_money = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def fund_type(self):
        return self._fund_type

    @fund_type.setter
    def fund_type(self, value):
        self._fund_type = value
    @property
    def install_num_list(self):
        return self._install_num_list

    @install_num_list.setter
    def install_num_list(self, value):
        if isinstance(value, list):
            self._install_num_list = list()
            for i in value:
                self._install_num_list.append(i)
    @property
    def isv_id(self):
        return self._isv_id

    @isv_id.setter
    def isv_id(self, value):
        self._isv_id = value
    @property
    def max_money_limit(self):
        return self._max_money_limit

    @max_money_limit.setter
    def max_money_limit(self, value):
        self._max_money_limit = value
    @property
    def merchant_info(self):
        return self._merchant_info

    @merchant_info.setter
    def merchant_info(self, value):
        if isinstance(value, list):
            self._merchant_info = list()
            for i in value:
                if isinstance(i, HbMerchantInfo):
                    self._merchant_info.append(i)
                else:
                    self._merchant_info.append(HbMerchantInfo.from_alipay_dict(i))
    @property
    def min_money_limit(self):
        return self._min_money_limit

    @min_money_limit.setter
    def min_money_limit(self, value):
        self._min_money_limit = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def subsidy_scope(self):
        return self._subsidy_scope

    @subsidy_scope.setter
    def subsidy_scope(self, value):
        self._subsidy_scope = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_name:
            if hasattr(self.activity_name, 'to_alipay_dict'):
                params['activity_name'] = self.activity_name.to_alipay_dict()
            else:
                params['activity_name'] = self.activity_name
        if self.aggr_id:
            if hasattr(self.aggr_id, 'to_alipay_dict'):
                params['aggr_id'] = self.aggr_id.to_alipay_dict()
            else:
                params['aggr_id'] = self.aggr_id
        if self.amount_budget:
            if hasattr(self.amount_budget, 'to_alipay_dict'):
                params['amount_budget'] = self.amount_budget.to_alipay_dict()
            else:
                params['amount_budget'] = self.amount_budget
        if self.budget_warning_mail_list:
            if hasattr(self.budget_warning_mail_list, 'to_alipay_dict'):
                params['budget_warning_mail_list'] = self.budget_warning_mail_list.to_alipay_dict()
            else:
                params['budget_warning_mail_list'] = self.budget_warning_mail_list
        if self.budget_warning_mobile_list:
            if hasattr(self.budget_warning_mobile_list, 'to_alipay_dict'):
                params['budget_warning_mobile_list'] = self.budget_warning_mobile_list.to_alipay_dict()
            else:
                params['budget_warning_mobile_list'] = self.budget_warning_mobile_list
        if self.budget_warning_money:
            if hasattr(self.budget_warning_money, 'to_alipay_dict'):
                params['budget_warning_money'] = self.budget_warning_money.to_alipay_dict()
            else:
                params['budget_warning_money'] = self.budget_warning_money
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.fund_type:
            if hasattr(self.fund_type, 'to_alipay_dict'):
                params['fund_type'] = self.fund_type.to_alipay_dict()
            else:
                params['fund_type'] = self.fund_type
        if self.install_num_list:
            if isinstance(self.install_num_list, list):
                for i in range(0, len(self.install_num_list)):
                    element = self.install_num_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.install_num_list[i] = element.to_alipay_dict()
            if hasattr(self.install_num_list, 'to_alipay_dict'):
                params['install_num_list'] = self.install_num_list.to_alipay_dict()
            else:
                params['install_num_list'] = self.install_num_list
        if self.isv_id:
            if hasattr(self.isv_id, 'to_alipay_dict'):
                params['isv_id'] = self.isv_id.to_alipay_dict()
            else:
                params['isv_id'] = self.isv_id
        if self.max_money_limit:
            if hasattr(self.max_money_limit, 'to_alipay_dict'):
                params['max_money_limit'] = self.max_money_limit.to_alipay_dict()
            else:
                params['max_money_limit'] = self.max_money_limit
        if self.merchant_info:
            if isinstance(self.merchant_info, list):
                for i in range(0, len(self.merchant_info)):
                    element = self.merchant_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.merchant_info[i] = element.to_alipay_dict()
            if hasattr(self.merchant_info, 'to_alipay_dict'):
                params['merchant_info'] = self.merchant_info.to_alipay_dict()
            else:
                params['merchant_info'] = self.merchant_info
        if self.min_money_limit:
            if hasattr(self.min_money_limit, 'to_alipay_dict'):
                params['min_money_limit'] = self.min_money_limit.to_alipay_dict()
            else:
                params['min_money_limit'] = self.min_money_limit
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.subsidy_scope:
            if hasattr(self.subsidy_scope, 'to_alipay_dict'):
                params['subsidy_scope'] = self.subsidy_scope.to_alipay_dict()
            else:
                params['subsidy_scope'] = self.subsidy_scope
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiMerchantActivityModifyModel()
        if 'activity_name' in d:
            o.activity_name = d['activity_name']
        if 'aggr_id' in d:
            o.aggr_id = d['aggr_id']
        if 'amount_budget' in d:
            o.amount_budget = d['amount_budget']
        if 'budget_warning_mail_list' in d:
            o.budget_warning_mail_list = d['budget_warning_mail_list']
        if 'budget_warning_mobile_list' in d:
            o.budget_warning_mobile_list = d['budget_warning_mobile_list']
        if 'budget_warning_money' in d:
            o.budget_warning_money = d['budget_warning_money']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'fund_type' in d:
            o.fund_type = d['fund_type']
        if 'install_num_list' in d:
            o.install_num_list = d['install_num_list']
        if 'isv_id' in d:
            o.isv_id = d['isv_id']
        if 'max_money_limit' in d:
            o.max_money_limit = d['max_money_limit']
        if 'merchant_info' in d:
            o.merchant_info = d['merchant_info']
        if 'min_money_limit' in d:
            o.min_money_limit = d['min_money_limit']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'subsidy_scope' in d:
            o.subsidy_scope = d['subsidy_scope']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FixFileInfo import FixFileInfo


class AlipayCommerceFixAttachmentUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceFixAttachmentUploadResponse, self).__init__()
        self._file_info = None

    @property
    def file_info(self):
        return self._file_info

    @file_info.setter
    def file_info(self, value):
        if isinstance(value, FixFileInfo):
            self._file_info = value
        else:
            self._file_info = FixFileInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceFixAttachmentUploadResponse, self).parse_response_content(response_content)
        if 'file_info' in response:
            self.file_info = response['file_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InstallmentMetaInfo(object):

    def __init__(self):
        self._end_term = None
        self._start_term = None
        self._value = None

    @property
    def end_term(self):
        return self._end_term

    @end_term.setter
    def end_term(self, value):
        self._end_term = value
    @property
    def start_term(self):
        return self._start_term

    @start_term.setter
    def start_term(self, value):
        self._start_term = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_term:
            if hasattr(self.end_term, 'to_alipay_dict'):
                params['end_term'] = self.end_term.to_alipay_dict()
            else:
                params['end_term'] = self.end_term
        if self.start_term:
            if hasattr(self.start_term, 'to_alipay_dict'):
                params['start_term'] = self.start_term.to_alipay_dict()
            else:
                params['start_term'] = self.start_term
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InstallmentMetaInfo()
        if 'end_term' in d:
            o.end_term = d['end_term']
        if 'start_term' in d:
            o.start_term = d['start_term']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MiniAppModelQueryResponse import MiniAppModelQueryResponse


class AlipayOpenMiniModelQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniModelQueryResponse, self).__init__()
        self._model_infos = None

    @property
    def model_infos(self):
        return self._model_infos

    @model_infos.setter
    def model_infos(self, value):
        if isinstance(value, list):
            self._model_infos = list()
            for i in value:
                if isinstance(i, MiniAppModelQueryResponse):
                    self._model_infos.append(i)
                else:
                    self._model_infos.append(MiniAppModelQueryResponse.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniModelQueryResponse, self).parse_response_content(response_content)
        if 'model_infos' in response:
            self.model_infos = response['model_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MicroPayOrderDetail import MicroPayOrderDetail


class AlipayMicropayOrderGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMicropayOrderGetResponse, self).__init__()
        self._micro_pay_order_detail = None

    @property
    def micro_pay_order_detail(self):
        return self._micro_pay_order_detail

    @micro_pay_order_detail.setter
    def micro_pay_order_detail(self, value):
        if isinstance(value, MicroPayOrderDetail):
            self._micro_pay_order_detail = value
        else:
            self._micro_pay_order_detail = MicroPayOrderDetail.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMicropayOrderGetResponse, self).parse_response_content(response_content)
        if 'micro_pay_order_detail' in response:
            self.micro_pay_order_detail = response['micro_pay_order_detail']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.StockPositionVO import StockPositionVO


class AntfortuneStockStocktoolDeliverQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneStockStocktoolDeliverQueryResponse, self).__init__()
        self._position_list = None
        self._user_id = None

    @property
    def position_list(self):
        return self._position_list

    @position_list.setter
    def position_list(self, value):
        if isinstance(value, list):
            self._position_list = list()
            for i in value:
                if isinstance(i, StockPositionVO):
                    self._position_list.append(i)
                else:
                    self._position_list.append(StockPositionVO.from_alipay_dict(i))
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AntfortuneStockStocktoolDeliverQueryResponse, self).parse_response_content(response_content)
        if 'position_list' in response:
            self.position_list = response['position_list']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TradeInformation(object):

    def __init__(self):
        self._commodity_name = None
        self._currency = None
        self._is_l_c_order = None
        self._is_l_c_received_by_one_touch = None
        self._order_amount = None
        self._order_id = None

    @property
    def commodity_name(self):
        return self._commodity_name

    @commodity_name.setter
    def commodity_name(self, value):
        self._commodity_name = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def is_l_c_order(self):
        return self._is_l_c_order

    @is_l_c_order.setter
    def is_l_c_order(self, value):
        self._is_l_c_order = value
    @property
    def is_l_c_received_by_one_touch(self):
        return self._is_l_c_received_by_one_touch

    @is_l_c_received_by_one_touch.setter
    def is_l_c_received_by_one_touch(self, value):
        self._is_l_c_received_by_one_touch = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.commodity_name:
            if hasattr(self.commodity_name, 'to_alipay_dict'):
                params['commodity_name'] = self.commodity_name.to_alipay_dict()
            else:
                params['commodity_name'] = self.commodity_name
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.is_l_c_order:
            if hasattr(self.is_l_c_order, 'to_alipay_dict'):
                params['is_l_c_order'] = self.is_l_c_order.to_alipay_dict()
            else:
                params['is_l_c_order'] = self.is_l_c_order
        if self.is_l_c_received_by_one_touch:
            if hasattr(self.is_l_c_received_by_one_touch, 'to_alipay_dict'):
                params['is_l_c_received_by_one_touch'] = self.is_l_c_received_by_one_touch.to_alipay_dict()
            else:
                params['is_l_c_received_by_one_touch'] = self.is_l_c_received_by_one_touch
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TradeInformation()
        if 'commodity_name' in d:
            o.commodity_name = d['commodity_name']
        if 'currency' in d:
            o.currency = d['currency']
        if 'is_l_c_order' in d:
            o.is_l_c_order = d['is_l_c_order']
        if 'is_l_c_received_by_one_touch' in d:
            o.is_l_c_received_by_one_touch = d['is_l_c_received_by_one_touch']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'order_id' in d:
            o.order_id = d['order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasRemitBeneficialinfoCertifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasRemitBeneficialinfoCertifyResponse, self).__init__()
        self._extend_info = None
        self._is_pass = None

    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def is_pass(self):
        return self._is_pass

    @is_pass.setter
    def is_pass(self, value):
        self._is_pass = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasRemitBeneficialinfoCertifyResponse, self).parse_response_content(response_content)
        if 'extend_info' in response:
            self.extend_info = response['extend_info']
        if 'is_pass' in response:
            self.is_pass = response['is_pass']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.UserInfoDetail import UserInfoDetail
from alipay.aop.api.domain.BankGoodsDetail import BankGoodsDetail
from alipay.aop.api.domain.OrderExtendParams import OrderExtendParams
from alipay.aop.api.domain.UserInfoDetail import UserInfoDetail


class MybankPaymentTradeBusinessOrderCreateModel(object):

    def __init__(self):
        self._amount = None
        self._biz_scene = None
        self._buyer_info = None
        self._currency_value = None
        self._goods_detail = None
        self._match_account_no = None
        self._order_extend_params = None
        self._out_trade_no = None
        self._product_code = None
        self._remark = None
        self._request_no = None
        self._seller_info = None
        self._timeout_express = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def buyer_info(self):
        return self._buyer_info

    @buyer_info.setter
    def buyer_info(self, value):
        if isinstance(value, UserInfoDetail):
            self._buyer_info = value
        else:
            self._buyer_info = UserInfoDetail.from_alipay_dict(value)
    @property
    def currency_value(self):
        return self._currency_value

    @currency_value.setter
    def currency_value(self, value):
        self._currency_value = value
    @property
    def goods_detail(self):
        return self._goods_detail

    @goods_detail.setter
    def goods_detail(self, value):
        if isinstance(value, list):
            self._goods_detail = list()
            for i in value:
                if isinstance(i, BankGoodsDetail):
                    self._goods_detail.append(i)
                else:
                    self._goods_detail.append(BankGoodsDetail.from_alipay_dict(i))
    @property
    def match_account_no(self):
        return self._match_account_no

    @match_account_no.setter
    def match_account_no(self, value):
        self._match_account_no = value
    @property
    def order_extend_params(self):
        return self._order_extend_params

    @order_extend_params.setter
    def order_extend_params(self, value):
        if isinstance(value, OrderExtendParams):
            self._order_extend_params = value
        else:
            self._order_extend_params = OrderExtendParams.from_alipay_dict(value)
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value
    @property
    def seller_info(self):
        return self._seller_info

    @seller_info.setter
    def seller_info(self, value):
        if isinstance(value, UserInfoDetail):
            self._seller_info = value
        else:
            self._seller_info = UserInfoDetail.from_alipay_dict(value)
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.buyer_info:
            if hasattr(self.buyer_info, 'to_alipay_dict'):
                params['buyer_info'] = self.buyer_info.to_alipay_dict()
            else:
                params['buyer_info'] = self.buyer_info
        if self.currency_value:
            if hasattr(self.currency_value, 'to_alipay_dict'):
                params['currency_value'] = self.currency_value.to_alipay_dict()
            else:
                params['currency_value'] = self.currency_value
        if self.goods_detail:
            if isinstance(self.goods_detail, list):
                for i in range(0, len(self.goods_detail)):
                    element = self.goods_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_detail[i] = element.to_alipay_dict()
            if hasattr(self.goods_detail, 'to_alipay_dict'):
                params['goods_detail'] = self.goods_detail.to_alipay_dict()
            else:
                params['goods_detail'] = self.goods_detail
        if self.match_account_no:
            if hasattr(self.match_account_no, 'to_alipay_dict'):
                params['match_account_no'] = self.match_account_no.to_alipay_dict()
            else:
                params['match_account_no'] = self.match_account_no
        if self.order_extend_params:
            if hasattr(self.order_extend_params, 'to_alipay_dict'):
                params['order_extend_params'] = self.order_extend_params.to_alipay_dict()
            else:
                params['order_extend_params'] = self.order_extend_params
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.request_no:
            if hasattr(self.request_no, 'to_alipay_dict'):
                params['request_no'] = self.request_no.to_alipay_dict()
            else:
                params['request_no'] = self.request_no
        if self.seller_info:
            if hasattr(self.seller_info, 'to_alipay_dict'):
                params['seller_info'] = self.seller_info.to_alipay_dict()
            else:
                params['seller_info'] = self.seller_info
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankPaymentTradeBusinessOrderCreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'buyer_info' in d:
            o.buyer_info = d['buyer_info']
        if 'currency_value' in d:
            o.currency_value = d['currency_value']
        if 'goods_detail' in d:
            o.goods_detail = d['goods_detail']
        if 'match_account_no' in d:
            o.match_account_no = d['match_account_no']
        if 'order_extend_params' in d:
            o.order_extend_params = d['order_extend_params']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'remark' in d:
            o.remark = d['remark']
        if 'request_no' in d:
            o.request_no = d['request_no']
        if 'seller_info' in d:
            o.seller_info = d['seller_info']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AssetInfoItem import AssetInfoItem


class AntMerchantExpandAssetinfoSyncModel(object):

    def __init__(self):
        self._asset_infos = None

    @property
    def asset_infos(self):
        return self._asset_infos

    @asset_infos.setter
    def asset_infos(self, value):
        if isinstance(value, list):
            self._asset_infos = list()
            for i in value:
                if isinstance(i, AssetInfoItem):
                    self._asset_infos.append(i)
                else:
                    self._asset_infos.append(AssetInfoItem.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.asset_infos:
            if isinstance(self.asset_infos, list):
                for i in range(0, len(self.asset_infos)):
                    element = self.asset_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.asset_infos[i] = element.to_alipay_dict()
            if hasattr(self.asset_infos, 'to_alipay_dict'):
                params['asset_infos'] = self.asset_infos.to_alipay_dict()
            else:
                params['asset_infos'] = self.asset_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandAssetinfoSyncModel()
        if 'asset_infos' in d:
            o.asset_infos = d['asset_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZolozAuthenticationCustomerSmilepayInitializeModel(object):

    def __init__(self):
        self._service_id = None
        self._service_params = None
        self._zimmetainfo = None

    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def service_params(self):
        return self._service_params

    @service_params.setter
    def service_params(self, value):
        self._service_params = value
    @property
    def zimmetainfo(self):
        return self._zimmetainfo

    @zimmetainfo.setter
    def zimmetainfo(self, value):
        self._zimmetainfo = value


    def to_alipay_dict(self):
        params = dict()
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.service_params:
            if hasattr(self.service_params, 'to_alipay_dict'):
                params['service_params'] = self.service_params.to_alipay_dict()
            else:
                params['service_params'] = self.service_params
        if self.zimmetainfo:
            if hasattr(self.zimmetainfo, 'to_alipay_dict'):
                params['zimmetainfo'] = self.zimmetainfo.to_alipay_dict()
            else:
                params['zimmetainfo'] = self.zimmetainfo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZolozAuthenticationCustomerSmilepayInitializeModel()
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'service_params' in d:
            o.service_params = d['service_params']
        if 'zimmetainfo' in d:
            o.zimmetainfo = d['zimmetainfo']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AddTagResult(object):

    def __init__(self):
        self._biz_id = None
        self._error_code = None
        self._error_message = None
        self._success = None
        self._trade_no = None
        self._type = None
        self._value = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.error_message:
            if hasattr(self.error_message, 'to_alipay_dict'):
                params['error_message'] = self.error_message.to_alipay_dict()
            else:
                params['error_message'] = self.error_message
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AddTagResult()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'error_message' in d:
            o.error_message = d['error_message']
        if 'success' in d:
            o.success = d['success']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'type' in d:
            o.type = d['type']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BoxDetail import BoxDetail


class BrandBoxDetail(object):

    def __init__(self):
        self._detail = None
        self._key = None

    @property
    def detail(self):
        return self._detail

    @detail.setter
    def detail(self, value):
        if isinstance(value, BoxDetail):
            self._detail = value
        else:
            self._detail = BoxDetail.from_alipay_dict(value)
    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value


    def to_alipay_dict(self):
        params = dict()
        if self.detail:
            if hasattr(self.detail, 'to_alipay_dict'):
                params['detail'] = self.detail.to_alipay_dict()
            else:
                params['detail'] = self.detail
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BrandBoxDetail()
        if 'detail' in d:
            o.detail = d['detail']
        if 'key' in d:
            o.key = d['key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityDataInfoSecuritydataQueryModel(object):

    def __init__(self):
        self._biz_id = None
        self._ext = None
        self._subject = None
        self._system_name = None
        self._type = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def system_name(self):
        return self._system_name

    @system_name.setter
    def system_name(self, value):
        self._system_name = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.system_name:
            if hasattr(self.system_name, 'to_alipay_dict'):
                params['system_name'] = self.system_name.to_alipay_dict()
            else:
                params['system_name'] = self.system_name
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityDataInfoSecuritydataQueryModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'ext' in d:
            o.ext = d['ext']
        if 'subject' in d:
            o.subject = d['subject']
        if 'system_name' in d:
            o.system_name = d['system_name']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AreaCode import AreaCode


class AlipayEcoLogisticsExpressNonserviceQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoLogisticsExpressNonserviceQueryResponse, self).__init__()
        self._area_codes = None

    @property
    def area_codes(self):
        return self._area_codes

    @area_codes.setter
    def area_codes(self, value):
        if isinstance(value, list):
            self._area_codes = list()
            for i in value:
                if isinstance(i, AreaCode):
                    self._area_codes.append(i)
                else:
                    self._area_codes.append(AreaCode.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayEcoLogisticsExpressNonserviceQueryResponse, self).parse_response_content(response_content)
        if 'area_codes' in response:
            self.area_codes = response['area_codes']
